# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from nexus_api_python_client.api_client import ApiClient
from nexus_api_python_client.exceptions import (
    ApiTypeError,
    ApiValueError
)


class RepositoryManagementApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_repository1(self, **kwargs):  # noqa: E501
        """create_repository1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository1(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AptHostedRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository1_with_http_info(**kwargs)  # noqa: E501

    def create_repository1_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository1_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AptHostedRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/apt/hosted', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository10(self, **kwargs):  # noqa: E501
        """create_repository10  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository10(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DockerHostedRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository10_with_http_info(**kwargs)  # noqa: E501

    def create_repository10_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository10  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository10_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DockerHostedRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository10" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/docker/hosted', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository11(self, **kwargs):  # noqa: E501
        """create_repository11  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository11(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GitLfsHostedRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository11_with_http_info(**kwargs)  # noqa: E501

    def create_repository11_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository11  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository11_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GitLfsHostedRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository11" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/gitlfs/hosted', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository2(self, **kwargs):  # noqa: E501
        """create_repository2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository2(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AptProxyRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository2_with_http_info(**kwargs)  # noqa: E501

    def create_repository2_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository2_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AptProxyRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/apt/proxy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository3(self, **kwargs):  # noqa: E501
        """create_repository3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository3(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GolangGroupRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository3_with_http_info(**kwargs)  # noqa: E501

    def create_repository3_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository3_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GolangGroupRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository3" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/go/group', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository4(self, **kwargs):  # noqa: E501
        """create_repository4  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository4(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GolangProxyRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository4_with_http_info(**kwargs)  # noqa: E501

    def create_repository4_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository4  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository4_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GolangProxyRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository4" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/go/proxy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository5(self, **kwargs):  # noqa: E501
        """create_repository5  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository5(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param BowerGroupRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository5_with_http_info(**kwargs)  # noqa: E501

    def create_repository5_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository5  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository5_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param BowerGroupRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository5" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/bower/group', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository6(self, **kwargs):  # noqa: E501
        """create_repository6  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository6(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param BowerProxyRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository6_with_http_info(**kwargs)  # noqa: E501

    def create_repository6_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository6  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository6_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param BowerProxyRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository6" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/bower/proxy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository7(self, **kwargs):  # noqa: E501
        """create_repository7  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository7(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param BowerHostedRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository7_with_http_info(**kwargs)  # noqa: E501

    def create_repository7_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository7  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository7_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param BowerHostedRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository7" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/bower/hosted', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository8(self, **kwargs):  # noqa: E501
        """create_repository8  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository8(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DockerGroupRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository8_with_http_info(**kwargs)  # noqa: E501

    def create_repository8_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository8  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository8_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DockerGroupRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository8" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/docker/group', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_repository9(self, **kwargs):  # noqa: E501
        """create_repository9  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository9(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DockerProxyRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_repository9_with_http_info(**kwargs)  # noqa: E501

    def create_repository9_with_http_info(self, **kwargs):  # noqa: E501
        """create_repository9  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_repository9_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DockerProxyRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_repository9" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/docker/proxy', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_repository(self, repository_name, **kwargs):  # noqa: E501
        """Delete repository of any format  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_repository(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to delete (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_repository_with_http_info(repository_name, **kwargs)  # noqa: E501

    def delete_repository_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """Delete repository of any format  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_repository_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to delete (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_repository" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `delete_repository`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/{repositoryName}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def disable_repository_health_check(self, repository_name, **kwargs):  # noqa: E501
        """Disable Repository Health Check. Proxy repositories only.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_repository_health_check(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to disable Repository Health Check for (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.disable_repository_health_check_with_http_info(repository_name, **kwargs)  # noqa: E501

    def disable_repository_health_check_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """Disable Repository Health Check. Proxy repositories only.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_repository_health_check_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to disable Repository Health Check for (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_repository_health_check" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `disable_repository_health_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/{repositoryName}/health-check', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def enable_repository_health_check(self, repository_name, **kwargs):  # noqa: E501
        """Enable Repository Health Check. Proxy repositories only.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_repository_health_check(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to enable Repository Health Check for (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.enable_repository_health_check_with_http_info(repository_name, **kwargs)  # noqa: E501

    def enable_repository_health_check_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """Enable Repository Health Check. Proxy repositories only.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_repository_health_check_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to enable Repository Health Check for (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method enable_repository_health_check" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `enable_repository_health_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/{repositoryName}/health-check', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_repositories(self, **kwargs):  # noqa: E501
        """List repositories  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_repositories(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_repositories_with_http_info(**kwargs)  # noqa: E501

    def get_repositories_with_http_info(self, **kwargs):  # noqa: E501
        """List repositories  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_repositories_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_repositories" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def invalidate_cache(self, repository_name, **kwargs):  # noqa: E501
        """Invalidate repository cache. Proxy or group repositories only.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invalidate_cache(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to invalidate cache (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.invalidate_cache_with_http_info(repository_name, **kwargs)  # noqa: E501

    def invalidate_cache_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """Invalidate repository cache. Proxy or group repositories only.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.invalidate_cache_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to invalidate cache (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method invalidate_cache" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `invalidate_cache`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/{repositoryName}/invalidate-cache', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def rebuild_index(self, repository_name, **kwargs):  # noqa: E501
        """Schedule a 'Repair - Rebuild repository search' Task. Hosted or proxy repositories only.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rebuild_index(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to rebuild index (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.rebuild_index_with_http_info(repository_name, **kwargs)  # noqa: E501

    def rebuild_index_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """Schedule a 'Repair - Rebuild repository search' Task. Hosted or proxy repositories only.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.rebuild_index_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: Name of the repository to rebuild index (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method rebuild_index" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `rebuild_index`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/{repositoryName}/rebuild-index', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository1(self, repository_name, **kwargs):  # noqa: E501
        """update_repository1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository1(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param AptHostedRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository1_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository1_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository1  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository1_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param AptHostedRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/apt/hosted/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository10(self, repository_name, **kwargs):  # noqa: E501
        """update_repository10  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository10(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param DockerHostedRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository10_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository10_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository10  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository10_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param DockerHostedRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository10" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository10`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/docker/hosted/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository11(self, repository_name, **kwargs):  # noqa: E501
        """update_repository11  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository11(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param GitLfsHostedRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository11_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository11_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository11  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository11_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param GitLfsHostedRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository11" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository11`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/gitlfs/hosted/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository2(self, repository_name, **kwargs):  # noqa: E501
        """update_repository2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository2(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param AptProxyRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository2_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository2_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository2_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param AptProxyRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository2" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/apt/proxy/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository3(self, repository_name, **kwargs):  # noqa: E501
        """update_repository3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository3(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param GolangGroupRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository3_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository3_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository3  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository3_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param GolangGroupRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository3" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository3`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/go/group/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository4(self, repository_name, **kwargs):  # noqa: E501
        """update_repository4  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository4(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param GolangProxyRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository4_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository4_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository4  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository4_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param GolangProxyRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository4" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository4`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/go/proxy/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository5(self, repository_name, **kwargs):  # noqa: E501
        """update_repository5  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository5(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param BowerGroupRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository5_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository5_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository5  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository5_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param BowerGroupRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository5" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository5`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/bower/group/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository6(self, repository_name, **kwargs):  # noqa: E501
        """update_repository6  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository6(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param BowerProxyRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository6_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository6_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository6  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository6_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param BowerProxyRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository6" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository6`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/bower/proxy/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository7(self, repository_name, **kwargs):  # noqa: E501
        """update_repository7  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository7(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param BowerHostedRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository7_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository7_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository7  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository7_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param BowerHostedRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository7" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository7`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/bower/hosted/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository8(self, repository_name, **kwargs):  # noqa: E501
        """update_repository8  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository8(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param DockerGroupRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository8_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository8_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository8  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository8_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param DockerGroupRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository8" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository8`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/docker/group/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_repository9(self, repository_name, **kwargs):  # noqa: E501
        """update_repository9  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository9(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param DockerProxyRepositoryApiRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_repository9_with_http_info(repository_name, **kwargs)  # noqa: E501

    def update_repository9_with_http_info(self, repository_name, **kwargs):  # noqa: E501
        """update_repository9  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_repository9_with_http_info(repository_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str repository_name: (required)
        :param DockerProxyRepositoryApiRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['repository_name', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_repository9" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'repository_name' is set
        if self.api_client.client_side_validation and ('repository_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['repository_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `repository_name` when calling `update_repository9`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'repository_name' in local_var_params:
            path_params['repositoryName'] = local_var_params['repository_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/beta/repositories/docker/proxy/{repositoryName}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class S3BlobStoreApiBucketConfiguration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bucket': 'S3BlobStoreApiBucket',
        'encryption': 'S3BlobStoreApiEncryption',
        'bucket_security': 'S3BlobStoreApiBucketSecurity',
        'advanced_bucket_connection': 'S3BlobStoreApiAdvancedBucketConnection'
    }

    attribute_map = {
        'bucket': 'bucket',
        'encryption': 'encryption',
        'bucket_security': 'bucketSecurity',
        'advanced_bucket_connection': 'advancedBucketConnection'
    }

    def __init__(self, bucket=None, encryption=None, bucket_security=None, advanced_bucket_connection=None, local_vars_configuration=None):  # noqa: E501
        """S3BlobStoreApiBucketConfiguration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bucket = None
        self._encryption = None
        self._bucket_security = None
        self._advanced_bucket_connection = None
        self.discriminator = None

        self.bucket = bucket
        if encryption is not None:
            self.encryption = encryption
        if bucket_security is not None:
            self.bucket_security = bucket_security
        if advanced_bucket_connection is not None:
            self.advanced_bucket_connection = advanced_bucket_connection

    @property
    def bucket(self):
        """Gets the bucket of this S3BlobStoreApiBucketConfiguration.  # noqa: E501


        :return: The bucket of this S3BlobStoreApiBucketConfiguration.  # noqa: E501
        :rtype: S3BlobStoreApiBucket
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this S3BlobStoreApiBucketConfiguration.


        :param bucket: The bucket of this S3BlobStoreApiBucketConfiguration.  # noqa: E501
        :type: S3BlobStoreApiBucket
        """
        if self.local_vars_configuration.client_side_validation and bucket is None:  # noqa: E501
            raise ValueError("Invalid value for `bucket`, must not be `None`")  # noqa: E501

        self._bucket = bucket

    @property
    def encryption(self):
        """Gets the encryption of this S3BlobStoreApiBucketConfiguration.  # noqa: E501


        :return: The encryption of this S3BlobStoreApiBucketConfiguration.  # noqa: E501
        :rtype: S3BlobStoreApiEncryption
        """
        return self._encryption

    @encryption.setter
    def encryption(self, encryption):
        """Sets the encryption of this S3BlobStoreApiBucketConfiguration.


        :param encryption: The encryption of this S3BlobStoreApiBucketConfiguration.  # noqa: E501
        :type: S3BlobStoreApiEncryption
        """

        self._encryption = encryption

    @property
    def bucket_security(self):
        """Gets the bucket_security of this S3BlobStoreApiBucketConfiguration.  # noqa: E501


        :return: The bucket_security of this S3BlobStoreApiBucketConfiguration.  # noqa: E501
        :rtype: S3BlobStoreApiBucketSecurity
        """
        return self._bucket_security

    @bucket_security.setter
    def bucket_security(self, bucket_security):
        """Sets the bucket_security of this S3BlobStoreApiBucketConfiguration.


        :param bucket_security: The bucket_security of this S3BlobStoreApiBucketConfiguration.  # noqa: E501
        :type: S3BlobStoreApiBucketSecurity
        """

        self._bucket_security = bucket_security

    @property
    def advanced_bucket_connection(self):
        """Gets the advanced_bucket_connection of this S3BlobStoreApiBucketConfiguration.  # noqa: E501


        :return: The advanced_bucket_connection of this S3BlobStoreApiBucketConfiguration.  # noqa: E501
        :rtype: S3BlobStoreApiAdvancedBucketConnection
        """
        return self._advanced_bucket_connection

    @advanced_bucket_connection.setter
    def advanced_bucket_connection(self, advanced_bucket_connection):
        """Sets the advanced_bucket_connection of this S3BlobStoreApiBucketConfiguration.


        :param advanced_bucket_connection: The advanced_bucket_connection of this S3BlobStoreApiBucketConfiguration.  # noqa: E501
        :type: S3BlobStoreApiAdvancedBucketConnection
        """

        self._advanced_bucket_connection = advanced_bucket_connection

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, S3BlobStoreApiBucketConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, S3BlobStoreApiBucketConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class DockerAttributes(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'v1_enabled': 'bool',
        'force_basic_auth': 'bool',
        'http_port': 'int',
        'https_port': 'int'
    }

    attribute_map = {
        'v1_enabled': 'v1Enabled',
        'force_basic_auth': 'forceBasicAuth',
        'http_port': 'httpPort',
        'https_port': 'httpsPort'
    }

    def __init__(self, v1_enabled=None, force_basic_auth=None, http_port=None, https_port=None, local_vars_configuration=None):  # noqa: E501
        """DockerAttributes - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._v1_enabled = None
        self._force_basic_auth = None
        self._http_port = None
        self._https_port = None
        self.discriminator = None

        self.v1_enabled = v1_enabled
        self.force_basic_auth = force_basic_auth
        if http_port is not None:
            self.http_port = http_port
        if https_port is not None:
            self.https_port = https_port

    @property
    def v1_enabled(self):
        """Gets the v1_enabled of this DockerAttributes.  # noqa: E501

        Whether to allow clients to use the V1 API to interact with this repository  # noqa: E501

        :return: The v1_enabled of this DockerAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._v1_enabled

    @v1_enabled.setter
    def v1_enabled(self, v1_enabled):
        """Sets the v1_enabled of this DockerAttributes.

        Whether to allow clients to use the V1 API to interact with this repository  # noqa: E501

        :param v1_enabled: The v1_enabled of this DockerAttributes.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and v1_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `v1_enabled`, must not be `None`")  # noqa: E501

        self._v1_enabled = v1_enabled

    @property
    def force_basic_auth(self):
        """Gets the force_basic_auth of this DockerAttributes.  # noqa: E501

        Whether to force authentication (Docker Bearer Token Realm required if false)  # noqa: E501

        :return: The force_basic_auth of this DockerAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._force_basic_auth

    @force_basic_auth.setter
    def force_basic_auth(self, force_basic_auth):
        """Sets the force_basic_auth of this DockerAttributes.

        Whether to force authentication (Docker Bearer Token Realm required if false)  # noqa: E501

        :param force_basic_auth: The force_basic_auth of this DockerAttributes.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and force_basic_auth is None:  # noqa: E501
            raise ValueError("Invalid value for `force_basic_auth`, must not be `None`")  # noqa: E501

        self._force_basic_auth = force_basic_auth

    @property
    def http_port(self):
        """Gets the http_port of this DockerAttributes.  # noqa: E501

        Create an HTTP connector at specified port  # noqa: E501

        :return: The http_port of this DockerAttributes.  # noqa: E501
        :rtype: int
        """
        return self._http_port

    @http_port.setter
    def http_port(self, http_port):
        """Sets the http_port of this DockerAttributes.

        Create an HTTP connector at specified port  # noqa: E501

        :param http_port: The http_port of this DockerAttributes.  # noqa: E501
        :type: int
        """

        self._http_port = http_port

    @property
    def https_port(self):
        """Gets the https_port of this DockerAttributes.  # noqa: E501

        Create an HTTPS connector at specified port  # noqa: E501

        :return: The https_port of this DockerAttributes.  # noqa: E501
        :rtype: int
        """
        return self._https_port

    @https_port.setter
    def https_port(self, https_port):
        """Sets the https_port of this DockerAttributes.

        Create an HTTPS connector at specified port  # noqa: E501

        :param https_port: The https_port of this DockerAttributes.  # noqa: E501
        :type: int
        """

        self._https_port = https_port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DockerAttributes):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DockerAttributes):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class HttpClientAttributes(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'blocked': 'bool',
        'auto_block': 'bool',
        'connection': 'HttpClientConnectionAttributes',
        'authentication': 'HttpClientConnectionAuthenticationAttributes'
    }

    attribute_map = {
        'blocked': 'blocked',
        'auto_block': 'autoBlock',
        'connection': 'connection',
        'authentication': 'authentication'
    }

    def __init__(self, blocked=None, auto_block=None, connection=None, authentication=None, local_vars_configuration=None):  # noqa: E501
        """HttpClientAttributes - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._blocked = None
        self._auto_block = None
        self._connection = None
        self._authentication = None
        self.discriminator = None

        self.blocked = blocked
        self.auto_block = auto_block
        if connection is not None:
            self.connection = connection
        if authentication is not None:
            self.authentication = authentication

    @property
    def blocked(self):
        """Gets the blocked of this HttpClientAttributes.  # noqa: E501

        Whether to block outbound connections on the repository  # noqa: E501

        :return: The blocked of this HttpClientAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._blocked

    @blocked.setter
    def blocked(self, blocked):
        """Sets the blocked of this HttpClientAttributes.

        Whether to block outbound connections on the repository  # noqa: E501

        :param blocked: The blocked of this HttpClientAttributes.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and blocked is None:  # noqa: E501
            raise ValueError("Invalid value for `blocked`, must not be `None`")  # noqa: E501

        self._blocked = blocked

    @property
    def auto_block(self):
        """Gets the auto_block of this HttpClientAttributes.  # noqa: E501

        Whether to auto-block outbound connections if remote peer is detected as unreachable/unresponsive  # noqa: E501

        :return: The auto_block of this HttpClientAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._auto_block

    @auto_block.setter
    def auto_block(self, auto_block):
        """Sets the auto_block of this HttpClientAttributes.

        Whether to auto-block outbound connections if remote peer is detected as unreachable/unresponsive  # noqa: E501

        :param auto_block: The auto_block of this HttpClientAttributes.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and auto_block is None:  # noqa: E501
            raise ValueError("Invalid value for `auto_block`, must not be `None`")  # noqa: E501

        self._auto_block = auto_block

    @property
    def connection(self):
        """Gets the connection of this HttpClientAttributes.  # noqa: E501


        :return: The connection of this HttpClientAttributes.  # noqa: E501
        :rtype: HttpClientConnectionAttributes
        """
        return self._connection

    @connection.setter
    def connection(self, connection):
        """Sets the connection of this HttpClientAttributes.


        :param connection: The connection of this HttpClientAttributes.  # noqa: E501
        :type: HttpClientConnectionAttributes
        """

        self._connection = connection

    @property
    def authentication(self):
        """Gets the authentication of this HttpClientAttributes.  # noqa: E501


        :return: The authentication of this HttpClientAttributes.  # noqa: E501
        :rtype: HttpClientConnectionAuthenticationAttributes
        """
        return self._authentication

    @authentication.setter
    def authentication(self, authentication):
        """Sets the authentication of this HttpClientAttributes.


        :param authentication: The authentication of this HttpClientAttributes.  # noqa: E501
        :type: HttpClientConnectionAuthenticationAttributes
        """

        self._authentication = authentication

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HttpClientAttributes):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HttpClientAttributes):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class HttpClientConnectionAttributes(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'retries': 'int',
        'user_agent_suffix': 'str',
        'timeout': 'int',
        'enable_circular_redirects': 'bool',
        'enable_cookies': 'bool'
    }

    attribute_map = {
        'retries': 'retries',
        'user_agent_suffix': 'userAgentSuffix',
        'timeout': 'timeout',
        'enable_circular_redirects': 'enableCircularRedirects',
        'enable_cookies': 'enableCookies'
    }

    def __init__(self, retries=None, user_agent_suffix=None, timeout=None, enable_circular_redirects=None, enable_cookies=None, local_vars_configuration=None):  # noqa: E501
        """HttpClientConnectionAttributes - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._retries = None
        self._user_agent_suffix = None
        self._timeout = None
        self._enable_circular_redirects = None
        self._enable_cookies = None
        self.discriminator = None

        if retries is not None:
            self.retries = retries
        if user_agent_suffix is not None:
            self.user_agent_suffix = user_agent_suffix
        if timeout is not None:
            self.timeout = timeout
        if enable_circular_redirects is not None:
            self.enable_circular_redirects = enable_circular_redirects
        if enable_cookies is not None:
            self.enable_cookies = enable_cookies

    @property
    def retries(self):
        """Gets the retries of this HttpClientConnectionAttributes.  # noqa: E501

        Total retries if the initial connection attempt suffers a timeout  # noqa: E501

        :return: The retries of this HttpClientConnectionAttributes.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this HttpClientConnectionAttributes.

        Total retries if the initial connection attempt suffers a timeout  # noqa: E501

        :param retries: The retries of this HttpClientConnectionAttributes.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                retries is not None and retries > 10):  # noqa: E501
            raise ValueError("Invalid value for `retries`, must be a value less than or equal to `10`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                retries is not None and retries < 0):  # noqa: E501
            raise ValueError("Invalid value for `retries`, must be a value greater than or equal to `0`")  # noqa: E501

        self._retries = retries

    @property
    def user_agent_suffix(self):
        """Gets the user_agent_suffix of this HttpClientConnectionAttributes.  # noqa: E501

        Custom fragment to append to User-Agent header in HTTP requests  # noqa: E501

        :return: The user_agent_suffix of this HttpClientConnectionAttributes.  # noqa: E501
        :rtype: str
        """
        return self._user_agent_suffix

    @user_agent_suffix.setter
    def user_agent_suffix(self, user_agent_suffix):
        """Sets the user_agent_suffix of this HttpClientConnectionAttributes.

        Custom fragment to append to User-Agent header in HTTP requests  # noqa: E501

        :param user_agent_suffix: The user_agent_suffix of this HttpClientConnectionAttributes.  # noqa: E501
        :type: str
        """

        self._user_agent_suffix = user_agent_suffix

    @property
    def timeout(self):
        """Gets the timeout of this HttpClientConnectionAttributes.  # noqa: E501

        Seconds to wait for activity before stopping and retrying the connection  # noqa: E501

        :return: The timeout of this HttpClientConnectionAttributes.  # noqa: E501
        :rtype: int
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this HttpClientConnectionAttributes.

        Seconds to wait for activity before stopping and retrying the connection  # noqa: E501

        :param timeout: The timeout of this HttpClientConnectionAttributes.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                timeout is not None and timeout > 3600):  # noqa: E501
            raise ValueError("Invalid value for `timeout`, must be a value less than or equal to `3600`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                timeout is not None and timeout < 1):  # noqa: E501
            raise ValueError("Invalid value for `timeout`, must be a value greater than or equal to `1`")  # noqa: E501

        self._timeout = timeout

    @property
    def enable_circular_redirects(self):
        """Gets the enable_circular_redirects of this HttpClientConnectionAttributes.  # noqa: E501

        Whether to enable redirects to the same location (may be required by some servers)  # noqa: E501

        :return: The enable_circular_redirects of this HttpClientConnectionAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._enable_circular_redirects

    @enable_circular_redirects.setter
    def enable_circular_redirects(self, enable_circular_redirects):
        """Sets the enable_circular_redirects of this HttpClientConnectionAttributes.

        Whether to enable redirects to the same location (may be required by some servers)  # noqa: E501

        :param enable_circular_redirects: The enable_circular_redirects of this HttpClientConnectionAttributes.  # noqa: E501
        :type: bool
        """

        self._enable_circular_redirects = enable_circular_redirects

    @property
    def enable_cookies(self):
        """Gets the enable_cookies of this HttpClientConnectionAttributes.  # noqa: E501

        Whether to allow cookies to be stored and used  # noqa: E501

        :return: The enable_cookies of this HttpClientConnectionAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._enable_cookies

    @enable_cookies.setter
    def enable_cookies(self, enable_cookies):
        """Sets the enable_cookies of this HttpClientConnectionAttributes.

        Whether to allow cookies to be stored and used  # noqa: E501

        :param enable_cookies: The enable_cookies of this HttpClientConnectionAttributes.  # noqa: E501
        :type: bool
        """

        self._enable_cookies = enable_cookies

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HttpClientConnectionAttributes):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HttpClientConnectionAttributes):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class Request(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'system_information': 'bool',
        'thread_dump': 'bool',
        'metrics': 'bool',
        'configuration': 'bool',
        'security': 'bool',
        'log': 'bool',
        'task_log': 'bool',
        'audit_log': 'bool',
        'jmx': 'bool',
        'limit_file_sizes': 'bool',
        'limit_zip_size': 'bool'
    }

    attribute_map = {
        'system_information': 'systemInformation',
        'thread_dump': 'threadDump',
        'metrics': 'metrics',
        'configuration': 'configuration',
        'security': 'security',
        'log': 'log',
        'task_log': 'taskLog',
        'audit_log': 'auditLog',
        'jmx': 'jmx',
        'limit_file_sizes': 'limitFileSizes',
        'limit_zip_size': 'limitZipSize'
    }

    def __init__(self, system_information=None, thread_dump=None, metrics=None, configuration=None, security=None, log=None, task_log=None, audit_log=None, jmx=None, limit_file_sizes=None, limit_zip_size=None, local_vars_configuration=None):  # noqa: E501
        """Request - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._system_information = None
        self._thread_dump = None
        self._metrics = None
        self._configuration = None
        self._security = None
        self._log = None
        self._task_log = None
        self._audit_log = None
        self._jmx = None
        self._limit_file_sizes = None
        self._limit_zip_size = None
        self.discriminator = None

        if system_information is not None:
            self.system_information = system_information
        if thread_dump is not None:
            self.thread_dump = thread_dump
        if metrics is not None:
            self.metrics = metrics
        if configuration is not None:
            self.configuration = configuration
        if security is not None:
            self.security = security
        if log is not None:
            self.log = log
        if task_log is not None:
            self.task_log = task_log
        if audit_log is not None:
            self.audit_log = audit_log
        if jmx is not None:
            self.jmx = jmx
        if limit_file_sizes is not None:
            self.limit_file_sizes = limit_file_sizes
        if limit_zip_size is not None:
            self.limit_zip_size = limit_zip_size

    @property
    def system_information(self):
        """Gets the system_information of this Request.  # noqa: E501


        :return: The system_information of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._system_information

    @system_information.setter
    def system_information(self, system_information):
        """Sets the system_information of this Request.


        :param system_information: The system_information of this Request.  # noqa: E501
        :type: bool
        """

        self._system_information = system_information

    @property
    def thread_dump(self):
        """Gets the thread_dump of this Request.  # noqa: E501


        :return: The thread_dump of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._thread_dump

    @thread_dump.setter
    def thread_dump(self, thread_dump):
        """Sets the thread_dump of this Request.


        :param thread_dump: The thread_dump of this Request.  # noqa: E501
        :type: bool
        """

        self._thread_dump = thread_dump

    @property
    def metrics(self):
        """Gets the metrics of this Request.  # noqa: E501


        :return: The metrics of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this Request.


        :param metrics: The metrics of this Request.  # noqa: E501
        :type: bool
        """

        self._metrics = metrics

    @property
    def configuration(self):
        """Gets the configuration of this Request.  # noqa: E501


        :return: The configuration of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this Request.


        :param configuration: The configuration of this Request.  # noqa: E501
        :type: bool
        """

        self._configuration = configuration

    @property
    def security(self):
        """Gets the security of this Request.  # noqa: E501


        :return: The security of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._security

    @security.setter
    def security(self, security):
        """Sets the security of this Request.


        :param security: The security of this Request.  # noqa: E501
        :type: bool
        """

        self._security = security

    @property
    def log(self):
        """Gets the log of this Request.  # noqa: E501


        :return: The log of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._log

    @log.setter
    def log(self, log):
        """Sets the log of this Request.


        :param log: The log of this Request.  # noqa: E501
        :type: bool
        """

        self._log = log

    @property
    def task_log(self):
        """Gets the task_log of this Request.  # noqa: E501


        :return: The task_log of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._task_log

    @task_log.setter
    def task_log(self, task_log):
        """Sets the task_log of this Request.


        :param task_log: The task_log of this Request.  # noqa: E501
        :type: bool
        """

        self._task_log = task_log

    @property
    def audit_log(self):
        """Gets the audit_log of this Request.  # noqa: E501


        :return: The audit_log of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._audit_log

    @audit_log.setter
    def audit_log(self, audit_log):
        """Sets the audit_log of this Request.


        :param audit_log: The audit_log of this Request.  # noqa: E501
        :type: bool
        """

        self._audit_log = audit_log

    @property
    def jmx(self):
        """Gets the jmx of this Request.  # noqa: E501


        :return: The jmx of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._jmx

    @jmx.setter
    def jmx(self, jmx):
        """Sets the jmx of this Request.


        :param jmx: The jmx of this Request.  # noqa: E501
        :type: bool
        """

        self._jmx = jmx

    @property
    def limit_file_sizes(self):
        """Gets the limit_file_sizes of this Request.  # noqa: E501


        :return: The limit_file_sizes of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._limit_file_sizes

    @limit_file_sizes.setter
    def limit_file_sizes(self, limit_file_sizes):
        """Sets the limit_file_sizes of this Request.


        :param limit_file_sizes: The limit_file_sizes of this Request.  # noqa: E501
        :type: bool
        """

        self._limit_file_sizes = limit_file_sizes

    @property
    def limit_zip_size(self):
        """Gets the limit_zip_size of this Request.  # noqa: E501


        :return: The limit_zip_size of this Request.  # noqa: E501
        :rtype: bool
        """
        return self._limit_zip_size

    @limit_zip_size.setter
    def limit_zip_size(self, limit_zip_size):
        """Sets the limit_zip_size of this Request.


        :param limit_zip_size: The limit_zip_size of this Request.  # noqa: E501
        :type: bool
        """

        self._limit_zip_size = limit_zip_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Request):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Request):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from nexus_api_python_client.api.blob_store_api import BlobStoreApi
from nexus_api_python_client.api.manage_iq_server_configuration_api import ManageIQServerConfigurationApi
from nexus_api_python_client.api.product_licensing_api import ProductLicensingApi
from nexus_api_python_client.api.repository_management_api import RepositoryManagementApi
from nexus_api_python_client.api.security_certificates_api import SecurityCertificatesApi
from nexus_api_python_client.api.security_management_api import SecurityManagementApi
from nexus_api_python_client.api.security_management_ldap_api import SecurityManagementLDAPApi
from nexus_api_python_client.api.security_management_privileges_api import SecurityManagementPrivilegesApi
from nexus_api_python_client.api.security_management_realms_api import SecurityManagementRealmsApi
from nexus_api_python_client.api.security_management_roles_api import SecurityManagementRolesApi
from nexus_api_python_client.api.security_management_users_api import SecurityManagementUsersApi
from nexus_api_python_client.api.assets_api import AssetsApi
from nexus_api_python_client.api.components_api import ComponentsApi
from nexus_api_python_client.api.content_selectors_api import ContentSelectorsApi
from nexus_api_python_client.api.email_api import EmailApi
from nexus_api_python_client.api.formats_api import FormatsApi
from nexus_api_python_client.api.lifecycle_api import LifecycleApi
from nexus_api_python_client.api.read_only_api import ReadOnlyApi
from nexus_api_python_client.api.repositories_api import RepositoriesApi
from nexus_api_python_client.api.routing_rules_api import RoutingRulesApi
from nexus_api_python_client.api.script_api import ScriptApi
from nexus_api_python_client.api.search_api import SearchApi
from nexus_api_python_client.api.status_api import StatusApi
from nexus_api_python_client.api.support_api import SupportApi
from nexus_api_python_client.api.tasks_api import TasksApi



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class S3BlobStoreApiAdvancedBucketConnection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'endpoint': 'str',
        'signer_type': 'str',
        'force_path_style': 'bool'
    }

    attribute_map = {
        'endpoint': 'endpoint',
        'signer_type': 'signerType',
        'force_path_style': 'forcePathStyle'
    }

    def __init__(self, endpoint=None, signer_type=None, force_path_style=None, local_vars_configuration=None):  # noqa: E501
        """S3BlobStoreApiAdvancedBucketConnection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._endpoint = None
        self._signer_type = None
        self._force_path_style = None
        self.discriminator = None

        if endpoint is not None:
            self.endpoint = endpoint
        if signer_type is not None:
            self.signer_type = signer_type
        if force_path_style is not None:
            self.force_path_style = force_path_style

    @property
    def endpoint(self):
        """Gets the endpoint of this S3BlobStoreApiAdvancedBucketConnection.  # noqa: E501

        A custom endpoint URL for third party object stores using the S3 API.  # noqa: E501

        :return: The endpoint of this S3BlobStoreApiAdvancedBucketConnection.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this S3BlobStoreApiAdvancedBucketConnection.

        A custom endpoint URL for third party object stores using the S3 API.  # noqa: E501

        :param endpoint: The endpoint of this S3BlobStoreApiAdvancedBucketConnection.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def signer_type(self):
        """Gets the signer_type of this S3BlobStoreApiAdvancedBucketConnection.  # noqa: E501

        An API signature version which may be required for third party object stores using the S3 API.  # noqa: E501

        :return: The signer_type of this S3BlobStoreApiAdvancedBucketConnection.  # noqa: E501
        :rtype: str
        """
        return self._signer_type

    @signer_type.setter
    def signer_type(self, signer_type):
        """Sets the signer_type of this S3BlobStoreApiAdvancedBucketConnection.

        An API signature version which may be required for third party object stores using the S3 API.  # noqa: E501

        :param signer_type: The signer_type of this S3BlobStoreApiAdvancedBucketConnection.  # noqa: E501
        :type: str
        """

        self._signer_type = signer_type

    @property
    def force_path_style(self):
        """Gets the force_path_style of this S3BlobStoreApiAdvancedBucketConnection.  # noqa: E501

        Setting this flag will result in path-style access being used for all requests.  # noqa: E501

        :return: The force_path_style of this S3BlobStoreApiAdvancedBucketConnection.  # noqa: E501
        :rtype: bool
        """
        return self._force_path_style

    @force_path_style.setter
    def force_path_style(self, force_path_style):
        """Sets the force_path_style of this S3BlobStoreApiAdvancedBucketConnection.

        Setting this flag will result in path-style access being used for all requests.  # noqa: E501

        :param force_path_style: The force_path_style of this S3BlobStoreApiAdvancedBucketConnection.  # noqa: E501
        :type: bool
        """

        self._force_path_style = force_path_style

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, S3BlobStoreApiAdvancedBucketConnection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, S3BlobStoreApiAdvancedBucketConnection):
            return True

        return self.to_dict() != other.to_dict()



from setuptools import setup, find_packages

NAME = "nexus-api-python-client"
VERSION = "1.0.4"

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Nexus Repository Manager Python API Client",
    author="Simone Bruzzechesse",
    author_email="b.sim619@gmail.com",
    url="",
    keywords=["Nexus API", "Python", "Nexus Repository Manager REST API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    Sonatype Nexus API Client for Python (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
    """
)
